<?php
/*
 ### General Functions eg setup theme etc.
 ##     Contains also some function hooks etc.
*/
if ( ! function_exists( 'photographer_setup' ) ) :

	function photographer_setup() {

		if ( ! isset( $content_width ) ) {
			$content_width = 800;
		}

		load_theme_textdomain( 'photographer', get_template_directory() . '/languages' );
		add_theme_support( 'automatic-feed-links' );
		add_theme_support( 'title-tag' );

		add_theme_support( 'post-thumbnails' );

		add_image_size( 'full-content-boxed-image', 1200, 540, true );
		add_image_size( 'content-sidebar-image', 800, 479, true );
		add_image_size( 'sidebar-content-image', 800, 479, true );
		add_image_size( 'scs-image', 600, 359, true );

		add_image_size( 'blog-list-image', 990, 580, true );

		$photographer_header_defaults = array(
			'default-image' => '',
			'random-default' => false,
			'width' => '1920',
			'height' => '850',
			'flex-height' => false,
			'flex-width' => false,
			'default-text-color' => '',
			'header-text' => false,
			'uploads' => true,
			'wp-head-callback' => '',
			'admin-head-callback' => '',
			'admin-preview-callback' => '',
		);

		add_theme_support('custom-header', $photographer_header_defaults);

		$photographer_bg_defaults = array(
			'default-color' => 'ffffff',
			'default-image' => '',
			'wp-head-callback' => 'photographer_bg_callback',
		);
		add_theme_support('custom-background', $photographer_bg_defaults);

		add_filter( 'image_size_names_choose', 'photographer_gallery_image_size' );
		function photographer_gallery_image_size( $sizes ) {
			$addsizes = array(
				'gallery-list-image' => __( 'Gallery Image', 'photographer' )
			);
			$newsizes = array_merge( $sizes, $addsizes );

			return $newsizes;
		}

		register_nav_menus( array(
			'primary-left'  => esc_html__( 'Primary Left', 'photographer' ),
			'primary-right' => esc_html__( 'Primary Right', 'photographer' ),
			'mobile' => esc_html__( 'Mobile Menu', 'photographer' ),
			'footer'        => esc_html__( 'Footer', 'photographer' ),
		) );

		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

	}
endif;
add_action( 'after_setup_theme', 'photographer_setup' );


if (!function_exists('photographer_bg_callback')):

	function photographer_bg_callback()
	{
		$background = set_url_scheme(get_background_image());
		$color = get_theme_mod('background_color', get_theme_support('custom-background', 'default-color'));

		if (!$background && !$color)
			return;

		$style = $color ? "background-color: #$color;" : '';

		if ($background) {
			$image = " background-image: url('$background');";

			$repeat = get_theme_mod('background_repeat', get_theme_support('custom-background', 'default-repeat'));
			if (!in_array($repeat, array('no-repeat', 'repeat-x', 'repeat-y', 'repeat')))
				$repeat = 'repeat';
			$repeat = " background-repeat: $repeat;";

			$position = get_theme_mod('background_position_x', get_theme_support('custom-background', 'default-position-x'));
			if (!in_array($position, array('center', 'right', 'left')))
				$position = 'left';
			$position = " background-position: top $position;";

			$attachment = get_theme_mod('background_attachment', get_theme_support('custom-background', 'default-attachment'));
			if (!in_array($attachment, array('fixed', 'scroll')))
				$attachment = 'scroll';
			$attachment = " background-attachment: $attachment;";

			$style .= $image . $repeat . $position . $attachment;
		}
		?>
		<style type="text/css" id="custom-background-css">
			body.custom-background {
			<?php echo trim( $style ); ?>
			}
		</style>
		<?php
	}
endif;

/*
 * ### Textdomain getter.
 */
if ( ! function_exists( 'photographer_textdomain' ) ):
	function photographer_textdomain() {
		$theme      = wp_get_theme();
		$textDomain = $theme->get( 'TextDomain' );

		return $textDomain;
	}
endif;

/*
 * Function that return the header image if any
 */
if (!function_exists('photographer_get_header_image')):
	function photographer_get_header_image()
	{
		$html = '';
		if (get_header_image() != ''):
			$html .= '<img class="img-responsive" src="' . get_header_image() . '" height="' . get_custom_header()->height . '" width="' . get_custom_header()->width . '" alt=""/>';
		else:
			return false;
		endif;
		return $html;
	}

	;
endif;

/*
* ### Return logo or site description  and/or tagline
*/

if ( ! function_exists( 'photographer_get_logo' ) ):
	function photographer_get_logo() {
		$prefix   = photographer_textdomain() . '_';
		$has_logo = get_theme_mod( $prefix . 'logo', '' );

		if ( ! empty( $has_logo ) ):

			return '<a href="' . esc_url( home_url( '/' ) ) . '" title="' . get_bloginfo( 'name' ) . '">
            <img src="' . esc_url( $has_logo ) . '" alt="' . get_bloginfo( 'name' ) . '-logo"/>
            </a>';

		else:

			return '<h1 class="site-title">
            <a href="' . esc_url( home_url( '/' ) ) . '">' . get_bloginfo( 'name' ) . '</a></h1>
            <h4 class="site-tagline">' . get_bloginfo( 'description' ) . '</h4>';

		endif;
	}
endif;
/*
 * ### Style the comments 
 */
if ( ! function_exists( 'photographer_comments' ) ) {
	function photographer_comments(
		$comment,
		$args,
		$depth
	) {
		$GLOBALS['comment'] = $comment;
		?>
	<li <?php comment_class( 'comment' ); ?> id="comment-<?php echo esc_attr( comment_ID() ); ?>">
		<div class="contents">
			<a target="_blank" href="<?php comment_author_url(); ?>" class="profile">
				<img src="//0.gravatar.com/avatar/<?php echo esc_attr( md5( $comment->comment_author_email ) ); ?>?s=96" class="gravatar" alt="<?php comment_author(); ?>">
			</a>
			<div class="main">
				<div class="commentinfo">
					<section class="meta">
						<div class="info"><?php esc_html_e( 'Posted', 'photographer' ); ?> <span class="date"><?php esc_html_e( 'on', 'photographer' ); ?> <i class="fa fa-clock-o"></i> <time
									datetime="<?php comment_date( 'Y-m-d' ); ?>"><?php comment_date( get_option( 'date_format' ) ); ?></time></span></div>
						<h4 class="author"><a href="<?php comment_author_url(); ?>"><img src="//0.gravatar.com/avatar/<?php echo esc_attr( md5( $comment->comment_author_email ) ); ?>?s=24"
						                                                                 class="gravatarsmall" alt="<?php comment_author(); ?>"> <?php comment_author(); ?></a></h4>
					</section>
					<div class="buttons">
						<?php comment_reply_link( array_merge( $args, array( 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
					</div>
				</div>
				<div class="body">
					<?php comment_text(); ?>
				</div>
				<hr>
			</div>
		</div>
		<?php
	}
}
function photographer_admin_head() {
	function photographer_get_collections(){
		$args = array(
			'post_type'=>'photographer-coll',
			'posts_per_page'=>-1,
			'orderby'=>'title',
			'order'=>'ASC'
		);
		$coll_array = array();
		$medium_array = array();
		$big_array = array();
		$collections = get_posts($args);

		$counter = 0;
		foreach($collections as $coll){

			$medium_array = array(
			'value' => $coll->ID,
			'text' => $coll->post_title,
			);

			$big_array[] = $medium_array;
		}
		$json = json_encode($big_array);

		return($json);
	}

	$collection = photographer_get_collections();
	?>
	<script type='text/javascript'>
		var photographer_sc_values = {
			'collections_array': <?php echo $collection; ?>
		};

	</script>
	<?php
}

add_action( 'admin_head', 'photographer_admin_head' );

/*
 * ## Pagination - default
 */

if ( ! function_exists( 'photographer_default_pagination' ) ):

	function photographer_default_pagination() {
		if ( is_singular() ) {
			return;
		}
		global $wp_query;
		if ( $wp_query->max_num_pages <= 1 ) {
			return;
		}

		$paged = get_query_var( 'paged' ) ? absint( get_query_var( 'paged' ) ) : 1;
		$max   = intval( $wp_query->max_num_pages );

		/**    Add current page to the array */
		if ( $paged >= 1 ) {
			$links[] = $paged;
		}

		/**    Add the pages around the current page to the array */
		if ( $paged >= 3 ) {
			$links[] = $paged - 1;
			$links[] = $paged - 2;
		}

		if ( ( $paged + 2 ) <= $max ) {
			$links[] = $paged + 2;
			$links[] = $paged + 1;
		}

		/**    Previous Post Link */
		if ( get_previous_posts_link() ) {
			printf( '<span>%s</span>' . "\n", get_previous_posts_link() );
		}

		/**    Link to first page, plus ellipses if necessary */
		if ( ! in_array( 1, $links ) ) {
			$class = 1 == $paged ? ' class="current page-numbers"' : '';

			printf( '<span%s><a href="%s">%s</a></span>' . "\n", $class, esc_url( get_pagenum_link( 1 ) ), '1' );

			if ( ! in_array( 2, $links ) ) {
				echo '<span>…</span>';
			}
		}

		/**    Link to current page, plus 2 pages in either direction if necessary */
		sort( $links );
		foreach ( (array) $links as $link ) {
			$class = $paged == $link ? ' class="current page-numbers"' : '';
			printf( '<span%s><a href="%s">%s</a></span>' . "\n", $class, esc_url( get_pagenum_link( $link ) ), $link );
		}

		/**    Link to last page, plus ellipses if necessary */
		if ( ! in_array( $max, $links ) ) {
			if ( ! in_array( $max - 1, $links ) ) {
				echo '<span>…</span>' . "\n";
			}

			$class = $paged == $max ? ' class="current page-numbers"' : '';
			printf( '<span%s><a href="%s">%s</a></span>' . "\n", $class, esc_url( get_pagenum_link( $max ) ), $max );
		}

		/**    Next Post Link */
		if ( get_next_posts_link() ) {
			printf( '<span>%s</span>' . "\n", get_next_posts_link() );
		}

	}

endif;

function photographer_upsell_notice(){
	// Enqueue the script
	wp_enqueue_script(
		'prefix-customizer-upsell',
		PHOTOGRAPHER_PATH_URI.'/js/upsell.js',
		array(), '1.0.0',
		true
	);

	wp_localize_script(
		'prefix-customizer-upsell',
		'prefixL10n',
		array(
			'prefixURL' => esc_url('http://ketchupthemes.com/photographer-theme'),
			'prefixLabel' => __('Upgrade To Premium', 'photographer') ,
			'paragraphText'=>__('Need user approoved galleries, and a lot more features?','photographer'),
			'premiumSpanTxt'=>__('- OR CHECK -','photographer'),
			'premiumDemoTxt'=>__('Premium Demo','photographer'),
			'premiumDemoUrl'=>esc_url('http://ketchupthemes.com/themes-demo/?theme=Photographer-New')
		)
	);


}
add_action('customize_controls_enqueue_scripts', 'photographer_upsell_notice');